==> apache-hop-2.1.0-src.tar.gz: apache-hop-2.1.0/plugins/transforms/joinrows/src/main/java/org/apache/hop/pipeline/transforms/joinrows/JoinRowsData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.joinrows;

import org.apache.hop.core.IRowSet;
import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

import java.io.*;
import java.util.List;

public class JoinRowsData extends BaseTransformData implements ITransformData {
  public File[] file;
  public FileInputStream[] fileInputStream;
  public DataInputStream[] dataInputStream;
  public IRowMeta[] fileRowMeta;

  public int[] size;
  public int[] position;
  public boolean[] restart;
  public IRowSet[] rs;
  public List<Object[]>[] cache;

  public boolean caching;

  public FileOutputStream[] fileOutputStream;
  public DataOutputStream[] dataOutputStream;

  public Object[][] joinrow;

  /** Keep track of which file temp file we're using... */
  public int filenr;

  public IRowMeta outputRowMeta;

  public JoinRowsData() {
    super();
  }
}

==> apache-hop-2.8.0-src.tar.gz: apache-hop-2.8.0/plugins/transforms/joinrows/src/main/java/org/apache/hop/pipeline/transforms/joinrows/JoinRowsData.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.hop.pipeline.transforms.joinrows;

import org.apache.hop.core.IRowSet;
import org.apache.hop.core.row.IRowMeta;
import org.apache.hop.pipeline.transform.BaseTransformData;
import org.apache.hop.pipeline.transform.ITransformData;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.util.List;

public class JoinRowsData extends BaseTransformData implements ITransformData {
  public File[] file;
  public FileInputStream[] fileInputStream;
  public DataInputStream[] dataInputStream;
  public IRowMeta[] fileRowMeta;

  public int[] size;
  public int[] position;
  public boolean[] restart;
  public IRowSet[] rs;
  public List<Object[]>[] cache;

  public boolean caching;

  public FileOutputStream[] fileOutputStream;
  public DataOutputStream[] dataOutputStream;

  public Object[][] joinrow;

  /** Keep track of which file temp file we're using... */
  public int filenr;

  public IRowMeta outputRowMeta;

  public JoinRowsData() {
    super();
  }
}
